#!/usr/bin/python
#
# BIND Resource Record Edit Dialog
#
# Jason Vas Dias <jvdias@redhat.com>, Red Hat Inc., Sept. 2004

import gtk
import gtk.glade
import gnome.ui
import gnome
import gobject

from RR import *
import RRGUI

class RREdit:
    def __init__(s, zoneTree, rr, dialog=None,read_only=False, read_only_message=''):
         s.rr = rr
         s.zoneTree=zoneTree
         s.bind = zoneTree.bind
         s.gui = s.bind.gui        
         s.widgets=[]
         s.read_only = read_only
         s.read_only_message = read_only_message
         if dialog == None:
             s.dialog = gtk.Dialog(rr.Type() + rr.value_label(''),
                                   s.gui.gui,
                                   gtk.DIALOG_MODAL | gtk.DIALOG_DESTROY_WITH_PARENT,
                                   (gtk.STOCK_OK, gtk.RESPONSE_ACCEPT,
                                    gtk.STOCK_CANCEL, gtk.RESPONSE_REJECT))
         else:
             s.dialog = dialog
#         s.scrolled_window = gtk.ScrolledWindow()          
         s.vbox=gtk.VBox()
#         s.scrolled_window.add_with_viewport(s.vbox)
         for k in rr.keys():
             labl = rr.value_label(k)
             if ( labl == None ):
                 continue
             frame = gtk.Frame(label=labl)
             rr_widget = rr.widget( s, RRGUI, k)
             widget = rr_widget.widget()
             frame.add(widget)             
             s.vbox.pack_start(frame)
             s.widgets.append(rr_widget)
             frame.show_all()
         if( rr.Type() in [ 'A','AAAA','NSAP' ]):
             s.create_reverse=gtk.CheckButton(label=_('Create Reverse Mapping Record'))
             s.create_reverse.set_active(True)
             s.vbox.pack_start(s.create_reverse)
         elif( rr.Type() == 'PTR' ):
             s.create_forward=gtk.CheckButton(label=_('Create Forward Mapping Record'))
             s.create_forward.set_active(True)
             s.vbox.pack_start(s.create_forward)         
 #        s.dialog.vbox.pack_start(s.scrolled_window)
         if  hasattr( s.dialog, 'vbox') :             
             s.dialog.vbox.pack_start(s.vbox)
         else:
             s.dialog.add(s.vbox)
#         s.scrolled_window.show()
         s.vbox.show_all()
         if(dialog == None):
             s.dialog.connect('response',s.on_response)
         s.dialog.show_all()
    
    def save(s):
        dirty=False
        for w in s.widgets:
            saved = w.save()
            if( saved not in [ True, False ]):
                debug( w.key, 'SAVE ERROR')
                return saved
            dirty = dirty or saved
            debug( 'SAVE:', w.__class__, w.key, w.attr, saved, dirty        )
        if dirty :
            if hasattr(s.rr,'update'):
                s.rr.update()
            s.zoneTree.load()
            if hasattr(s.rr,'zone') and hasattr(s.rr.zone,'zone_origin'):
                origin = s.rr.zone.zone_origin
                nmdcKey = s.rr.zone.nmdcKey
                parent = nmdcKey[:-1]
                zone = s.bind.zone(origin,parent)
                if ( zone != None ):
                    zone['dirty'] = True
                    debug( 'SET DIRTY', nmdcKey)
            if( hasattr(s,'create_reverse') and s.create_reverse.get_active() ):
                view=None
                if hasattr(s.rr,'zone') and hasattr(s.rr.zone,'nmdcKey'):
                    if s.rr.zone.nmdcKey[0] == 'view':
                        view = s.bind.views[ s.rr.zone.nmdcKey[1].strip('"') ]['view']
                debug( 'CREATING REVERSE MAPPING', str(s.rr.ADDRESS),str(s.rr.name),view)
                s.bind.add_host(str(s.rr.ADDRESS),str(s.rr.Name()),view=view,reverse_only=True)
            elif( hasattr(s,'create_forward') and s.create_forward.get_active() ):
                view=None
                if hasattr(s.rr,'zone') and hasattr(s.rr.zone,'nmdcKey'):
                    if s.rr.zone.nmdcKey[0] == 'view':
                        view = s.bind.views[ s.rr.zone.nmdcKey[1].strip('"') ]['view']
                debug( 'CREATING FORWARD MAPPING',str(s.rr.name),str(s.rr.PTRDNAME),view)
                s.bind.add_host(s.rr.name.label(),str(s.rr.PTRDNAME),view=view,forward_only=True)                
        return None
                    
    def on_response(s, dialog, response_id):
        if(response_id == gtk.RESPONSE_ACCEPT):
            if not s.read_only:
                debug( 'SAVE')
                e = s.save()
                if e != None:
                    s.bind.gui.modalError(s.bind.gui.gui,_('Record Save Error'), e)
                    return False
            else:
                s.bind.gui.warning(s.bind.gui.gui,_('Cannot Save'),s.read_only_message)
        elif(response_id == gtk.RESPONSE_REJECT):
            debug( 'CANCEL')
        dialog.destroy()
        return False
        
    
